# This file is generated by numpy's build process
# It contains system_info results at the time of building this package.
from enum import Enum
from numpy._core._multiarray_umath import (
    __cpu_features__,
    __cpu_baseline__,
    __cpu_dispatch__,
)

__all__ = ["show_config"]
_built_with_meson = True


class DisplayModes(Enum):
    stdout = "stdout"
    dicts = "dicts"


def _cleanup(d):
    """
    Removes empty values in a `dict` recursively
    This ensures we remove values that Meson could not provide to CONFIG
    """
    if isinstance(d, dict):
        return {k: _cleanup(v) for k, v in d.items() if v and _cleanup(v)}
    else:
        return d


CONFIG = _cleanup(
    {
        "Compilers": {
            "c": {
                "name": "clang",
                "linker": r"ld.lld",
                "version": "19.1.6",
                "commands": r"clang",
                "args": r"-mtune=generic, -march=x86-64, -g2, -pipe, -fPIC, -fno-plt, -Wformat, -Wformat-security, -D_FORTIFY_SOURCE=2, -fstack-protector-strong, --param=ssp-buffer-size=32, -fasynchronous-unwind-tables, -ftree-vectorize, -feliminate-unused-debug-types, -fno-omit-frame-pointer, -mno-omit-leaf-frame-pointer, -Wall, -Wno-error, -Wp,-D_REENTRANT, -O3",
                "linker args": r"-Wl,-O1, -Wl,-z,relro, -Wl,-z,now, -Wl,-z,max-page-size=0x1000, -Wl,-Bsymbolic-functions, -Wl,--sort-common, -Wl,-z,pack-relative-relocs, -mtune=generic, -march=x86-64, -g2, -pipe, -fPIC, -fno-plt, -Wformat, -Wformat-security, -D_FORTIFY_SOURCE=2, -fstack-protector-strong, --param=ssp-buffer-size=32, -fasynchronous-unwind-tables, -ftree-vectorize, -feliminate-unused-debug-types, -fno-omit-frame-pointer, -mno-omit-leaf-frame-pointer, -Wall, -Wno-error, -Wp,-D_REENTRANT, -O3",
            },
            "cython": {
                "name": "cython",
                "linker": r"cython",
                "version": "3.0.12",
                "commands": r"cython",
                "args": r"",
                "linker args": r"",
            },
            "c++": {
                "name": "clang",
                "linker": r"ld.lld",
                "version": "19.1.6",
                "commands": r"clang++",
                "args": r"-mtune=generic, -march=x86-64, -g2, -pipe, -fPIC, -fno-plt, -D_FORTIFY_SOURCE=2, -fstack-protector-strong, --param=ssp-buffer-size=32, -fasynchronous-unwind-tables, -ftree-vectorize, -feliminate-unused-debug-types, -fno-omit-frame-pointer, -mno-omit-leaf-frame-pointer, -Wall, -Wno-error, -Wp,-D_REENTRANT, -O3",
                "linker args": r"-Wl,-O1, -Wl,-z,relro, -Wl,-z,now, -Wl,-z,max-page-size=0x1000, -Wl,-Bsymbolic-functions, -Wl,--sort-common, -Wl,-z,pack-relative-relocs, -mtune=generic, -march=x86-64, -g2, -pipe, -fPIC, -fno-plt, -D_FORTIFY_SOURCE=2, -fstack-protector-strong, --param=ssp-buffer-size=32, -fasynchronous-unwind-tables, -ftree-vectorize, -feliminate-unused-debug-types, -fno-omit-frame-pointer, -mno-omit-leaf-frame-pointer, -Wall, -Wno-error, -Wp,-D_REENTRANT, -O3",
            },
        },
        "Machine Information": {
            "host": {
                "cpu": "x86_64",
                "family": "x86_64",
                "endian": "little",
                "system": "linux",
            },
            "build": {
                "cpu": "x86_64",
                "family": "x86_64",
                "endian": "little",
                "system": "linux",
            },
            "cross-compiled": bool("False".lower().replace("false", "")),
        },
        "Build Dependencies": {
            "blas": {
                "name": "openblas",
                "found": bool("True".lower().replace("false", "")),
                "version": "0.3.26",
                "detection method": "pkgconfig",
                "include directory": r"/usr/include",
                "lib directory": r"/usr/lib64",
                "openblas configuration": r"USE_64BITINT= DYNAMIC_ARCH= DYNAMIC_OLDER= NO_CBLAS= NO_LAPACK=1 NO_LAPACKE=1 NO_AFFINITY=1 USE_OPENMP=1 CORE2 MAX_THREADS=128",
                "pc file directory": r"/usr/lib64/pkgconfig",
            },
            "lapack": {
                "name": "lapack",
                "found": bool("True".lower().replace("false", "")),
                "version": "3.10.1",
                "detection method": "pkgconfig",
                "include directory": r"/usr/include",
                "lib directory": r"/usr/lib64",
                "openblas configuration": r"unknown",
                "pc file directory": r"/usr/lib64/pkgconfig",
            },
        },
        "Python Information": {
            "path": r"/usr/bin/python3",
            "version": "3.12",
        },
        "SIMD Extensions": {
            "baseline": __cpu_baseline__,
            "found": [
                feature for feature in __cpu_dispatch__ if __cpu_features__[feature]
            ],
            "not found": [
                feature for feature in __cpu_dispatch__ if not __cpu_features__[feature]
            ],
        },
    }
)


def _check_pyyaml():
    import yaml

    return yaml


def show(mode=DisplayModes.stdout.value):
    """
    Show libraries and system information on which NumPy was built
    and is being used

    Parameters
    ----------
    mode : {`'stdout'`, `'dicts'`}, optional.
        Indicates how to display the config information.
        `'stdout'` prints to console, `'dicts'` returns a dictionary
        of the configuration.

    Returns
    -------
    out : {`dict`, `None`}
        If mode is `'dicts'`, a dict is returned, else None

    See Also
    --------
    get_include : Returns the directory containing NumPy C
                  header files.

    Notes
    -----
    1. The `'stdout'` mode will give more readable
       output if ``pyyaml`` is installed

    """
    if mode == DisplayModes.stdout.value:
        try:  # Non-standard library, check import
            yaml = _check_pyyaml()

            print(yaml.dump(CONFIG))
        except ModuleNotFoundError:
            import warnings
            import json

            warnings.warn("Install `pyyaml` for better output", stacklevel=1)
            print(json.dumps(CONFIG, indent=2))
    elif mode == DisplayModes.dicts.value:
        return CONFIG
    else:
        raise AttributeError(
            f"Invalid `mode`, use one of: {', '.join([e.value for e in DisplayModes])}"
        )


def show_config(mode=DisplayModes.stdout.value):
    return show(mode)


show_config.__doc__ = show.__doc__
show_config.__module__ = "numpy"
